@@ -207,7 +207,7 @@ void check_load_balancer(t_config *config) {
 						close(sock);
 						connect_to->available = true;
 					} else {
-						log_string(config->system_logfile, "FastCGI server is still unavailable");
+						log_string(config->system_logfile, "FastCGI server %s is still (partially) unavailable", fcgi_server->fcgi_id);
 					}
 				}
 				connect_to = connect_to->next;
