@@ -29,7 +29,7 @@ typedef struct type_cgi_info {
 	t_cgi_type type;
 	time_t deadline;
 
-	int to_cgi, from_cgi, cgi_error, highest_fd;
+	int to_cgi, from_cgi, cgi_error;
 
 	char *input_buffer, *error_buffer;
 	int input_buffer_size, error_buffer_size;
