@@ -623,6 +623,7 @@ int parse_request(t_session *session, int total_bytes) {
 		conn = strlower(remove_spaces(conn));
 	}
 	session->keep_alive = false;
+
 	switch (*str_end) {
 		case '0':
 			if ((conn != NULL) && (session->kept_alive < session->binding->max_keepalive)) {
@@ -804,12 +805,13 @@ int get_path_info(t_session *session) {
  */
 int serve_client(t_session *session) {
 	int result, length;
-	char *search, *conffile, *qmark;
+	char *search, *conffile, *qmark, chr;
 	t_host *host_record;
 	t_access access;
+	t_deny_body *deny_body;
 #ifdef HAVE_TOOLKIT
 	int i;
-	char *new_uri;
+	t_toolkit_options options;
 #endif
 
 	if ((result = fetch_request(session)) != 200) {
@@ -848,24 +850,63 @@ int serve_client(t_session *session) {
 		}
 	}
 
+	/* Deny matching bodies
+	 */
+	if (session->body != NULL) {
+		chr = *(session->body + session->content_length);
+		*(session->body + session->content_length) = '\0';
+
+		deny_body = session->host->deny_body;
+		while (deny_body != NULL) {
+			if (strpcmp(session->body, &(deny_body->pattern)) == 0) {
+				if ((session->config->ban_on_denied_body > 0) && ip_allowed(&(session->ip_address), session->config->banlist_mask)) {
+					ban_ip(&(session->ip_address), session->config->ban_on_denied_body, session->config->kick_on_ban);
+					log_system(session, "Client banned because of denied body");
+				}
+				log_string(session->host->error_logfile, "Request denied because of unallowed body content");
+				log_garbage(session);
+
+				*(session->body + session->content_length) = chr;
+				return 403;
+			}
+			deny_body = deny_body->next;
+		}
+
+		*(session->body + session->content_length) = chr;
+	}
+
 #ifdef HAVE_TOOLKIT
 	/* URL toolkit
 	 */
+	options.new_url = NULL;
+	options.website_root = session->host->website_root;
+	options.fastcgi_server = NULL;
+	options.ban = 0;
+	options.url_toolkit = session->config->url_toolkit;
+
 	if ((session->request_method != PUT) && (session->request_method != DELETE)) {
 		for (i = 0; i < session->host->toolkit_rules.size; i++) {
-			if ((result = use_toolkit(session->uri, session->host->toolkit_rules.item[i], session->config->url_toolkit, &new_uri, session->host->website_root, &(session->toolkit_fastcgi))) == UT_ERROR) {
+			if ((result = use_toolkit(session->uri, session->host->toolkit_rules.item[i], &options)) == UT_ERROR) {
 				return 500;
 			}
-			if (new_uri != NULL) {
-				if (register_tempdata(&(session->tempdata), new_uri, tc_data) == -1) {
-					free(new_uri);
+
+			if ((options.ban > 0) && ip_allowed(&(session->ip_address), session->config->banlist_mask)) {
+				ban_ip(&(session->ip_address), options.ban, session->config->kick_on_ban);
+				log_system(session, "Client banned because of URL match in UrlToolkit rule");
+				return 403;
+			}
+
+			session->toolkit_fastcgi = options.fastcgi_server;
+			if (options.new_url != NULL) {
+				if (register_tempdata(&(session->tempdata), options.new_url, tc_data) == -1) {
+					free(options.new_url);
 					return 500;
 				}
-				session->uri = new_uri;
+				session->uri = options.new_url;
 			}
 
 			if (result == UT_REDIRECT) {
-				session->location = strdup(new_uri);
+				session->location = strdup(options.new_url);
 				session->cause_of_301 = location;
 				return 301;
 			}
@@ -979,14 +1020,6 @@ int serve_client(t_session *session) {
 		case not_found:
 			if (session->request_method == DELETE) {
 				return 404;
-			} else if (session->request_method != PUT) {
-				if (session->host->use_gz_file) {
-					if ((search = get_headerfield("Accept-Encoding:", session->headerfields)) != NULL) {
-						if ((strstr(search, "gzip")) != NULL) {
-							session->accept_gzip = true;
-						}
-					}
-				}
 			}
 	}
 
@@ -1101,16 +1134,8 @@ void handle_request_result(t_session *session, int result) {
 		case fe_FORCE_QUIT:
 			log_system(session, "Client kicked");
 			break;
-		case rr_CMD_INJECTION:
-			if (ip_allowed(&(session->ip_address), session->config->banlist_mask)) {
-				ban_ip(&(session->ip_address), session->config->ban_on_cmdi, session->config->kick_on_ban);
-				log_system(session, "Client banned because of command injection");
-			}
-			send_code(session, 400);
-			log_request(session, 400);
-			break;
 		case rr_SQL_INJECTION:
-			if (ip_allowed(&(session->ip_address), session->config->banlist_mask)) {
+			if ((session->config->ban_on_sqli > 0) && ip_allowed(&(session->ip_address), session->config->banlist_mask)) {
 				ban_ip(&(session->ip_address), session->config->ban_on_sqli, session->config->kick_on_ban);
 				log_system(session, "Client banned because of SQL injection");
 			}
@@ -1925,11 +1950,12 @@ int run_server(t_settings *settings) {
 
 	signal(SIGTERM, SIG_DFL);
 
+	close_bindings(config->binding);
+
 	disconnect_clients(config);
 #ifdef HAVE_COMMAND
 	disconnect_admins();
 #endif
-	close_bindings(config->binding);
 
 #ifdef HAVE_COMMAND
 	binding = config->command_port;
