@@ -140,7 +140,7 @@ static bool basic_http_authentication(t_session *session, char *auth_str) {
 
 	if (decode_base64(auth_user)) {
 		auth_passwd = auth_user;
-		while ((*auth_passwd != ':') && (auth_passwd != '\0')) {
+		while ((*auth_passwd != ':') && (*auth_passwd != '\0')) {
 			auth_passwd++;
 		}
 		if (*auth_passwd == ':') {
