@@ -73,14 +73,16 @@ t_headerfield *parse_headerfields(char *line) {
 char *get_headerfield(char *key, t_headerfield *headerfields) {
 	int len;
 
-	if (key != NULL) {
-		len = strlen(key);
-		while (headerfields != NULL) {
-			if (strncasecmp(headerfields->data, key, len) == 0) {
-				return headerfields->data + headerfields->value_offset;
-			}
-			headerfields = headerfields->next;
+	if ((key == NULL) || (headerfields == NULL)) {
+		return NULL;
+	}
+
+	len = strlen(key);
+	while (headerfields != NULL) {
+		if (strncasecmp(headerfields->data, key, len) == 0) {
+			return headerfields->data + headerfields->value_offset;
 		}
+		headerfields = headerfields->next;
 	}
 
 	return NULL;
@@ -173,22 +175,6 @@ bool in_charlist(char *item, t_charlist *list) {
 	return false;
 }
 
-#ifdef DEBUG
-void print_charlist(t_charlist *list) {
-	int i;
-
-	printf("print_charlist()::start\n");
-	if (list != NULL) {
-		for (i = 0; i < list->size; i++) {
-			printf("[%s]\n", *(list->item + i));
-		}
-	} else {
-		printf("(NULL)\n");
-	}
-	printf("print_charlist()::stop\n");
-}
-#endif
-
 void remove_charlist(t_charlist *list) {
 	if (list != NULL) {
 		if (list->size > 0) {
