@@ -5,6 +5,7 @@
 #include <stdbool.h>
 #include <string.h>
 #include <limits.h>
+#include <regex.h>
 #include "global.h"
 #include "alternative.h"
 
@@ -304,43 +305,6 @@ bool forbidden_chars_present(char *str) {
 	return false;
 }
 
-/* Prevent Command injection.
- */
-int prevent_cmdi(char *str) {
-	int result = 0;
-	short low, high;
-	char value;
-
-	if (str == NULL) {
-		return 0;
-	}
-
-	if (strncasecmp(str, "http://", 7) == 0) {
-		memcpy(str, "xxxx", 4);
-		result++;
-	}
-
-	if (str != NULL) {
-		while (*str != '\0') {
-			if ((value = *str) == '%') {
-				if ((high = hex_to_int(*(str + 1))) != -1) {
-					if ((low = hex_to_int(*(str + 2))) != -1) {
-						value = (char)(high<<4) + low;
-					}
-				}
-			}
-
-			if ((value == '|') || (value == ';') || (value == '`')) {
-				*str = '_';
-				result += 1;
-			}
-			str++;
-		}
-	}
-
-	return result;
-}
-
 /* Prevent SQL injection
  */
 int prevent_sqli(char *str, int length, char **newstr) {
@@ -703,3 +667,7 @@ int add_str(char **buffer, int *size, int extra_size, int *len, char *str) {
 
 	return 0;
 }
+
+int strpcmp(char *str, regex_t *regexp) {
+	return (regexec(regexp, str, 0, NULL, 0) == 0) ? 0 : -1;
+}
