@@ -1,8 +1,10 @@
 #ifndef _LIBSTR_H
 #define _LIBSTR_H
 
+#include "config.h"
 #include <sys/types.h>
 #include <stdbool.h>
+#include <regex.h>
 
 int  str2int(const char *str);
 char *remove_spaces(char *str);
@@ -24,5 +26,6 @@ bool min_strlen(char *str, int n);
 int  header_to_variable(char *header, char *variable, int size);
 int  filesize2str(char *buffer, int len, off_t fsize);
 int  add_str(char **buffer, int *size, int extra_size, int *len, char *str);
+int strpcmp(char *str, regex_t *regexp);
 
 #endif
