@@ -81,17 +81,18 @@ static char *secure_string(char *str) {
 void log_pid(t_config *config, pid_t pid) {
 	FILE *fp;
 
-	if ((fp = fopen(config->pidfile, "w")) != NULL) {
-		fprintf(fp, "%d\n", (int)pid);
-		fclose(fp);
-		if (chmod(config->pidfile, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH) == -1) {
-			fprintf(stderr, "Warning: can't chmod PID file %s. Make sure it's only writable for root!\n", config->pidfile);
-		}
-		if (chown(config->pidfile, 0, 0) == -1) {
-			fprintf(stderr, "Warning: can't chown PID file %s. Make sure it's owned by root!\n", config->pidfile);
-		}
-	} else {
+	if ((fp = fopen(config->pidfile, "w")) == NULL) {
 		fprintf(stderr, "Warning: can't write PID file %s.\n", config->pidfile);
+		return;
+	}
+
+	fprintf(fp, "%d\n", (int)pid);
+	fclose(fp);
+	if (chmod(config->pidfile, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH) == -1) {
+		fprintf(stderr, "Warning: can't chmod PID file %s. Make sure it's only writable for root!\n", config->pidfile);
+	}
+	if (chown(config->pidfile, 0, 0) == -1) {
+		fprintf(stderr, "Warning: can't chown PID file %s. Make sure it's owned by root!\n", config->pidfile);
 	}
 }
 
@@ -127,7 +128,7 @@ void log_system(t_session *session, char *mesg) {
 
 	if (mesg == NULL) {
 		return;
-	} else if ((fp = fopen(session->config->system_logfile, "a")) != NULL) {
+	} else if ((fp = fopen(session->config->system_logfile, "a")) == NULL) {
 		return;
 	}
 
@@ -145,7 +146,7 @@ void log_file_error(t_session *session, char *file, char *mesg) {
 
 	if ((file == NULL) || (mesg == NULL)) {
 		return;
-	} else if ((fp = fopen(session->host->error_logfile, "a")) != NULL) {
+	} else if ((fp = fopen(session->host->error_logfile, "a")) == NULL) {
 		return;
 	}
 
