@@ -5,7 +5,7 @@
 #include "global.h"
 #include "session.h"
 
-#define FCGI_BUFFER_SIZE 64 * KILOBYTE
+#define FCGI_BUFFER_SIZE (64 * KILOBYTE - 1)
 
 typedef struct {
 	int           sock;
