@@ -12,6 +12,7 @@
 #ifdef HAVE_SSL
 #include <time.h>
 #endif
+#include <regex.h>
 #include "serverconfig.h"
 #include "libstr.h"
 #include "libfs.h"
@@ -90,7 +91,6 @@ static t_host *new_host(void) {
 #ifdef HAVE_XSLT
 		host->use_xslt           = false;
 #endif
-		host->prevent_cmdi       = false;
 		host->prevent_sqli       = false;
 		host->prevent_xss        = false;
 		host->prevent_csrf       = false;
@@ -99,6 +99,7 @@ static t_host *new_host(void) {
 		host->trigger_on_cgi_status = true;
 		init_charlist(&(host->fast_cgi));
 		host->secure_url         = true;
+		host->deny_body          = NULL;
 
 		host->next               = NULL;
 	} else {
@@ -259,11 +260,11 @@ t_config *default_config(void) {
 		config->garbage_logfile    = NULL;
 		config->logfile_mask       = NULL;
 
+		config->ban_on_denied_body = 0;
 		config->ban_on_garbage     = 0;
 		config->ban_on_max_per_ip  = 2;
 		config->ban_on_flooding    = 0;
 		config->ban_on_max_request_size = 0;
-		config->ban_on_cmdi        = 0;
 		config->ban_on_sqli        = 0;
 		config->ban_on_timeout     = 0;
 		config->ban_on_wrong_password = 0;
@@ -552,10 +553,16 @@ int check_configuration(t_config *config) {
 				return -1;
 			}
 		}
+
 		if ((host->wrap_cgi != NULL) && (host->fast_cgi.size != 0)) {
 			fprintf(stderr, "The host '%s' contains both a WrapCGI and FastCGI option.\n", *(host->hostname.item));
 			return -1;
 		}
+
+		if (host->show_index && (host->fast_cgi.size > 0)) {
+			fprintf(stderr, "Warning: both FastCGI and ShowIndex are enabled for host %s. This can cause undesired behaviour.\n", *(host->hostname.item));
+		}
+
 		host = host->next;
 	}
 
@@ -656,8 +663,8 @@ static bool system_setting(char *key, char *value, t_config *config) {
 		if ((config->banlist_mask = parse_accesslist(value, false, config->banlist_mask)) != NULL) {
 			return true;
 		}
-	} else if (strcmp(key, "banoncmdi") == 0) {
-		if ((config->ban_on_cmdi = str2int(value)) != -1) {
+	} else if (strcmp(key, "banondeniedbody") == 0) {
+		if ((config->ban_on_denied_body = str2int(value)) != -1) {
 			return true;
 		}
 	} else if (strcmp(key, "banonflooding") == 0) {
@@ -1077,7 +1084,8 @@ static bool user_setting(char *key, char *value, t_host *host, t_tempdata **temp
 
 static bool host_setting(char *key, char *value, t_host *host) {
 	char *botname;
-	t_denybotlist *denybot;
+	t_denybotlist *deny_bot;
+	t_deny_body *deny_body;
 
 	if (strcmp(key, "accesslogfile") == 0) {
 		if (*value == '/') {
@@ -1093,15 +1101,33 @@ static bool host_setting(char *key, char *value, t_host *host) {
 				}
 			}
 		}
+	} else if (strcmp(key, "denybody") == 0) {
+		if (host->deny_body == NULL) {
+			host->deny_body = (t_deny_body*)malloc(sizeof(t_deny_body));
+			deny_body = host->deny_body;
+		} else {
+			deny_body = host->deny_body;
+			while (deny_body->next != NULL) {
+				deny_body = deny_body->next;
+			}
+			deny_body->next = (t_deny_body*)malloc(sizeof(t_deny_body));
+			deny_body = deny_body->next;
+		}
+		if (deny_body != NULL) {
+			deny_body->next = NULL;
+			if (regcomp(&(deny_body->pattern), value, REG_EXTENDED | REG_NOSUB) == 0) {
+				return true;
+			}
+		}
 	} else if (strcmp(key, "denybot") == 0) {
 		if (split_string(value, &botname, &value, ':') == 0) {
-			if ((denybot = (t_denybotlist*)malloc(sizeof(t_denybotlist))) != NULL) {
-				denybot->next = host->deny_bot;
-				host->deny_bot = denybot;
+			if ((deny_bot = (t_denybotlist*)malloc(sizeof(t_denybotlist))) != NULL) {
+				deny_bot->next = host->deny_bot;
+				host->deny_bot = deny_bot;
 
-				init_charlist(&(denybot->uri));
-				if ((denybot->bot = strdup(botname)) != NULL) {
-					if (parse_charlist(value, &(denybot->uri)) == 0) {
+				init_charlist(&(deny_bot->uri));
+				if ((deny_bot->bot = strdup(botname)) != NULL) {
+					if (parse_charlist(value, &(deny_bot->uri)) == 0) {
 						return true;
 					}
 				}
@@ -1137,10 +1163,6 @@ static bool host_setting(char *key, char *value, t_host *host) {
 				}
 			}
 		}
-	} else if (strcmp(key, "preventcmdi") == 0) {
-		if (parse_yesno(value, &(host->prevent_cmdi)) == 0) {
-			return true;
-		}
 	} else if (strcmp(key, "preventcsrf") == 0) {
 		if (parse_yesno(value, &(host->prevent_csrf)) == 0) {
 			return true;
