@@ -26,6 +26,11 @@ typedef enum { hiawatha, common, extended } t_log_format;
 typedef enum { windows, cygwin } t_platform;
 #endif
 
+typedef struct type_deny_body {
+	regex_t pattern;
+	struct type_deny_body *next;
+} t_deny_body;
+
 typedef struct type_cgi_handler {
 	char          *handler;
 	t_charlist    extension;
@@ -193,6 +198,7 @@ typedef struct type_host {
 	bool          enable_path_info;
 	bool          trigger_on_cgi_status;
 	t_charlist    fast_cgi;
+	t_deny_body   *deny_body;
 
 	struct type_host *next;
 
@@ -241,6 +247,7 @@ typedef struct type_config {
 	t_platform    platform;
 #endif
 
+	int           ban_on_denied_body;
 	int           ban_on_garbage;
 	int           ban_on_max_per_ip;
 	int           ban_on_flooding;
