@@ -33,9 +33,7 @@ static void clear_session(t_session *session) {
 	session->uri_is_dir = false;
 	session->request_uri = NULL;
 	session->request_method = unknown;
-	session->keep_alive = false;
 	session->extension = NULL;
-	session->accept_gzip = false;
 	session->encode_gzip = false;
 	session->path_info = NULL;
 	session->alias_used = false;
