@@ -71,7 +71,7 @@ extern char *hs_contyp;
 /* Read a file from disk and send it to the client.
  */
 int send_file(t_session *session) {
-	char *referer, *buffer = NULL, value[VALUE_SIZE + 1], *dot, *date, *range, *range_begin, *range_end, *new_fod;
+	char *referer, *buffer = NULL, value[VALUE_SIZE + 1], *pos, *date, *range, *range_begin, *range_end, *new_fod;
 	long bytes_read, total_bytes, size, speed;
 	off_t file_size, send_begin, send_end, send_size;
 	int  retval, handle;
@@ -104,8 +104,8 @@ int send_file(t_session *session) {
 				}
 
 				if (prot_oke) {
-					if ((dot = strchr(referer, '/')) != NULL) {
-						*dot = '\0';
+					if ((pos = strchr(referer, '/')) != NULL) {
+						*pos = '\0';
 					}
 					for (size = 0; size < session->host->image_referer.size; size++) {
 						if (strstr(referer, *(session->host->image_referer.item + size)) != NULL) {
@@ -113,8 +113,8 @@ int send_file(t_session *session) {
 							break;
 						}
 					}
-					if (dot != NULL) {
-						*dot = '/';
+					if (pos != NULL) {
+						*pos = '/';
 					}
 				}
 			}
@@ -137,19 +137,27 @@ int send_file(t_session *session) {
 			}
 		}
 	}
-	
-	/* Open the file for reading
-	 */
+
 	handle = -1;
-	if (session->accept_gzip) {
-		size = strlen(session->file_on_disk);
-		memcpy(session->file_on_disk + size, ".gz\0", 4);
-		if ((handle = open(session->file_on_disk, O_RDONLY)) != -1) {
-			session->encode_gzip = true;
-		} else {
-			*(session->file_on_disk + size) = '\0';
+
+	/* gzip content encoding
+	 */
+	if (session->host->use_gz_file) {
+		if ((pos = get_headerfield("Accept-Encoding:", session->headerfields)) != NULL) {
+			if ((strstr(pos, "gzip")) != NULL) {
+				size = strlen(session->file_on_disk);
+				memcpy(session->file_on_disk + size, ".gz\0", 4);
+				if ((handle = open(session->file_on_disk, O_RDONLY)) != -1) {
+					session->encode_gzip = true;
+				} else {
+					*(session->file_on_disk + size) = '\0';
+				}
+			}
 		}
 	}
+
+	/* Open the file for reading
+	 */
 	if (handle == -1) {
 		if ((handle = open(session->file_on_disk, O_RDONLY)) == -1) {
 			if (errno == EACCES) {
@@ -199,12 +207,12 @@ int send_file(t_session *session) {
 
 	/* Set throttlespeed
 	 */
-	dot = session->uri + session->uri_len;
-	while ((*dot != '.') && (dot != session->uri)) {
-		dot--;
+	pos = session->uri + session->uri_len;
+	while ((*pos != '.') && (pos != session->uri)) {
+		pos--;
 	}
-	if (*dot == '.') {
-		if ((speed = get_throttlespeed(dot, session->config->throttle)) != 0) {
+	if (*pos == '.') {
+		if ((speed = get_throttlespeed(pos, session->config->throttle)) != 0) {
 			if ((session->throttle == 0) || (speed < session->throttle)) {
 				session->throttle = speed;
 			}
@@ -590,22 +598,6 @@ int execute_cgi(t_session *session) {
 		}
 	}
 
-	if (session->host->prevent_cmdi) {
-		/* Prevent Command injection
-		 */
-		if ((prevent_cmdi(session->vars) > 0) && (session->config->ban_on_cmdi > 0)) {
-			return rr_CMD_INJECTION;
-		}
-		if ((prevent_cmdi(session->cookie) > 0) && (session->config->ban_on_cmdi > 0)) {
-			return rr_CMD_INJECTION;
-		}
-		/*
-		if ((prevent_CMDi(session->body) > 0) && (session->config->ban_on_cmdi > 0)) {
-			return rr_CMD_INJECTION;
-		}
-		*/
-	}
-
 	cgi_info.type = session->cgi_type;
 	cgi_info.input_buffer_size = cgi_info.error_buffer_size = CGI_BUFFER_SIZE;
 	cgi_info.input_len = cgi_info.error_len = 0;
