@@ -88,7 +88,51 @@ bool toolkit_setting(char *key, char *value, t_url_toolkit *toolkit) {
 			}
 			split_string(rest, &value, &rest, ' ');
 			
-			if (strcasecmp(value, "rewrite") == 0) {
+			if (strcasecmp(value, "ban") == 0) {
+				/* Match UseFastCGI
+				 */
+				new_rule->action = ta_match_ban;
+				new_rule->value = str2int(rest);
+			} else if (strcasecmp(value, "call") == 0) {
+				/* Match Call
+				 */
+				new_rule->action = ta_match_call;
+				if (strlen(rest) == 0) {
+					return false;
+				} else if ((new_rule->parameter = strdup(rest)) == NULL) {
+					return false;
+				}
+			} else if (strcasecmp(value, "denyaccess") == 0) {
+				/* Match DenyAccess
+				 */
+				new_rule->action = ta_match_deny_access;
+			} else if (strcasecmp(value, "exit") == 0) {
+				/* Match Exit
+				 */
+				new_rule->action = ta_match_exit;
+			} else if (strcasecmp(value, "goto") == 0) {
+				/* Match Goto
+				 */
+				new_rule->action = ta_match_goto;
+				if (strlen(rest) == 0) {
+					return false;
+				} else if ((new_rule->parameter = strdup(rest)) == NULL) {
+					return false;
+				}
+			} else if (strcasecmp(value, "redirect") == 0) {
+				/* Match Redirect
+				 */
+				new_rule->action = ta_match_redirect;
+				if (strlen(rest) == 0) {
+					return false;
+				} else if ((new_rule->parameter = strdup(rest)) == NULL) {
+					return false;
+				}
+			} else if (strcasecmp(value, "return") == 0) {
+				/* Match Return
+				 */
+				new_rule->action = ta_match_return;
+			} else if (strcasecmp(value, "rewrite") == 0) {
 				/* Match Rewrite
 				 */
 				new_rule->action = ta_match_rewrite;
@@ -122,45 +166,6 @@ bool toolkit_setting(char *key, char *value, t_url_toolkit *toolkit) {
 						return false;
 					}
 				}
-			} else if (strcasecmp(value, "redirect") == 0) {
-				/* Match Redirect
-				 */
-				new_rule->action = ta_match_redirect;
-				if (strlen(rest) == 0) {
-					return false;
-				} else if ((new_rule->parameter = strdup(rest)) == NULL) {
-					return false;
-				}
-			} else if (strcasecmp(value, "goto") == 0) {
-				/* Match Goto
-				 */
-				new_rule->action = ta_match_goto;
-				if (strlen(rest) == 0) {
-					return false;
-				} else if ((new_rule->parameter = strdup(rest)) == NULL) {
-					return false;
-				}
-			} else if (strcasecmp(value, "call") == 0) {
-				/* Match Call
-				 */
-				new_rule->action = ta_match_call;
-				if (strlen(rest) == 0) {
-					return false;
-				} else if ((new_rule->parameter = strdup(rest)) == NULL) {
-					return false;
-				}
-			} else if (strcasecmp(value, "return") == 0) {
-				/* Match Return
-				 */
-				new_rule->action = ta_match_return;
-			} else if (strcasecmp(value, "exit") == 0) {
-				/* Match Exit
-				 */
-				new_rule->action = ta_match_exit;
-			} else if (strcasecmp(value, "denyaccess") == 0) {
-				/* Match DenyAccess
-				 */
-				new_rule->action = ta_match_deny_access;
 			} else if (strcasecmp(value, "skip") == 0) {
 				/* Match Skip
 				 */
@@ -331,7 +336,7 @@ static int do_rewrite(char *url, regex_t *regexp, char *rep, char **new_url, int
 	return 0;
 }
 
-int use_toolkit(char *url, char *toolkit_id, t_url_toolkit *url_toolkit, char **new_url, char *website_root, char **fastcgi_server) {
+int use_toolkit(char *url, char *toolkit_id, t_toolkit_options *options) {
 	t_url_toolkit *toolkit;
 	t_toolkit_rule *rule;
 	bool replaced = false;
@@ -339,10 +344,14 @@ int use_toolkit(char *url, char *toolkit_id, t_url_toolkit *url_toolkit, char **
 	t_fsbool is_dir;
 	char *file, *qmark;
 
-	*new_url = NULL;
-	*fastcgi_server = NULL;
+	if (options == NULL) {
+		return UT_ERROR;
+	}
 
-	if ((toolkit = find_toolkit(toolkit_id, url_toolkit)) == NULL) {
+	options->new_url = NULL;
+	options->fastcgi_server = NULL;
+
+	if ((toolkit = find_toolkit(toolkit_id, options->url_toolkit)) == NULL) {
 		return UT_ERROR;
 	}
 
@@ -352,18 +361,18 @@ int use_toolkit(char *url, char *toolkit_id, t_url_toolkit *url_toolkit, char **
 			skip--;
 		} else switch (rule->action) {
 			case ta_match_rewrite:
-				if (do_rewrite(url, &(rule->pattern), rule->parameter, new_url, rule->match_loop) == -1) {
-					if (*new_url != NULL) {
-						free(*new_url);
-						*new_url = NULL;
+				if (do_rewrite(url, &(rule->pattern), rule->parameter, &(options->new_url), rule->match_loop) == -1) {
+					if (options->new_url != NULL) {
+						free(options->new_url);
+						options->new_url = NULL;
 					}
 					return UT_ERROR;
 				}
-				if (*new_url != NULL) {
+				if (options->new_url != NULL) {
 					if (replaced) {
 						free(url);
 					}
-					url = *new_url;
+					url = options->new_url;
 					replaced = true;
 
 					if (rule->done == td_return) {
@@ -372,24 +381,24 @@ int use_toolkit(char *url, char *toolkit_id, t_url_toolkit *url_toolkit, char **
 						return UT_EXIT;
 					}
 				} else if (replaced) {
-					*new_url = url;
+					options->new_url = url;
 				}
 				break;
 			case ta_match_redirect:
-				if (do_rewrite(url, &(rule->pattern), rule->parameter, new_url, rule->match_loop) == -1) {
-					if (*new_url != NULL) {
-						free(*new_url);
-						*new_url = NULL;
+				if (do_rewrite(url, &(rule->pattern), rule->parameter, &(options->new_url), rule->match_loop) == -1) {
+					if (options->new_url != NULL) {
+						free(options->new_url);
+						options->new_url = NULL;
 					}
 					return UT_ERROR;
 				}
-				if (*new_url != NULL) {
+				if (options->new_url != NULL) {
 					if (replaced) {
 						free(url);
 					}
 					return UT_REDIRECT;
 				} else if (replaced) {
-					*new_url = url;
+					options->new_url = url;
 				}
 				break;
 			case ta_call:
@@ -404,19 +413,19 @@ int use_toolkit(char *url, char *toolkit_id, t_url_toolkit *url_toolkit, char **
 					return UT_ERROR;
 				}
 
-				if ((result = use_toolkit(url, rule->parameter, url_toolkit, new_url, website_root, fastcgi_server)) == UT_ERROR) {
-					if (*new_url != NULL) {
-						free(*new_url);
-						*new_url = NULL;
+				if ((result = use_toolkit(url, rule->parameter, options)) == UT_ERROR) {
+					if (options->new_url != NULL) {
+						free(options->new_url);
+						options->new_url = NULL;
 					}
 					return UT_ERROR;
 				}
 
-				if (*new_url != NULL) {
+				if (options->new_url != NULL) {
 					if (replaced) {
 						free(url);
 					}
-					url = *new_url;
+					url = options->new_url;
 					replaced = true;
 				}
 
@@ -426,6 +435,12 @@ int use_toolkit(char *url, char *toolkit_id, t_url_toolkit *url_toolkit, char **
 					return UT_RETURN;
 				}
 				break;
+			case ta_match_ban:
+				if (regexec(&(rule->pattern), url, 0, NULL, 0) == 0) {
+					options->ban = rule->value;
+					return UT_EXIT;
+				}
+				break;
 			case ta_match_deny_access:
 				if (regexec(&(rule->pattern), url, 0, NULL, 0) == 0) {
 					return UT_DENY_ACCESS;
@@ -438,7 +453,7 @@ int use_toolkit(char *url, char *toolkit_id, t_url_toolkit *url_toolkit, char **
 				break;
 			case ta_match_fastcgi:
 				if (regexec(&(rule->pattern), url, 0, NULL, 0) == 0) {
-					*fastcgi_server = rule->parameter;
+					options->fastcgi_server = rule->parameter;
 					return UT_EXIT;
 				}
 				break;
@@ -459,7 +474,7 @@ int use_toolkit(char *url, char *toolkit_id, t_url_toolkit *url_toolkit, char **
 				if (valid_uri(url) == false) {
 					break;
 				}
-				if ((file = make_path(website_root, url)) == NULL) {
+				if ((file = make_path(options->website_root, url)) == NULL) {
 					return UT_ERROR;
 				}
 
