@@ -17,7 +17,8 @@
 
 typedef enum { ta_match_rewrite, ta_match_goto, ta_match_call, ta_match_return, 
                ta_match_exit, ta_match_skip, ta_call, ta_match_deny_access,
-			   ta_match_redirect, ta_match_fastcgi, ta_skip, ta_requesturi} t_toolkit_action;
+               ta_match_redirect, ta_match_fastcgi, ta_match_ban,
+               ta_skip, ta_requesturi} t_toolkit_action;
 typedef enum { td_continue, td_return, td_exit } t_toolkit_done;
 
 typedef struct type_toolkit_rule {
@@ -38,9 +39,17 @@ typedef struct type_url_toolkit {
 	struct type_url_toolkit *next;
 } t_url_toolkit;
 
+typedef struct type_toolkit_options {
+	char *new_url;
+	char *website_root;
+	char *fastcgi_server;
+	int ban;
+	t_url_toolkit *url_toolkit;
+} t_toolkit_options;
+
 t_url_toolkit *find_toolkit(char *toolkit_id, t_url_toolkit *url_toolkit);
 bool toolkit_setting(char *key, char *value, t_url_toolkit *toolkit);
 bool toolkit_rules_oke(t_url_toolkit *url_toolkit);
-int use_toolkit(char *url, char *toolkit_id, t_url_toolkit *url_toolkit, char **new_url, char *website_root, char **fastcgi_server);
+int use_toolkit(char *url, char *toolkit_id, t_toolkit_options *options);
 
 #endif
