@@ -337,8 +337,8 @@ int check_main_config(char *config_dir) {
 				}
 				add_result(&haystack, info, info, needle->file, needle->linenr);
 			} else {
-				printf("Duplicate hostname '%s' found on line %d in '%s/%s'.\n", item, needle->linenr, config_dir, needle->file);
-				errors++;
+				printf("Warning: duplicate hostname '%s' found on line %d in '%s/%s'.\n", item, needle->linenr, config_dir, needle->file);
+				//errors++;
 			}
 		}
 		free(rest);
@@ -539,8 +539,9 @@ int check_main_config(char *config_dir) {
 #ifdef HAVE_TOOLKIT
 void check_url_toolkit(char *config_dir, char **toolkit_id) {
 	t_line *config = NULL;
-	char input[MAX_INPUT_SIZE + 1], **id, *url, *new_url, *toolkit_fastcgi;
+	char input[MAX_INPUT_SIZE + 1], **id, *url;
 	t_url_toolkit *url_toolkit, *toolkit = NULL, *new_toolkit;
+	t_toolkit_options options;
 	bool in_rule_section = false;
 	int result = 0;
 
@@ -627,13 +628,18 @@ void check_url_toolkit(char *config_dir, char **toolkit_id) {
 			printf("Bad URL: missing leading slash.\n");
 		}
 
+		options.new_url = NULL;
+		options.website_root = ".";
+		options.fastcgi_server = NULL;
+		options.url_toolkit = url_toolkit;
+
 		id = toolkit_id;
 		while (*id != NULL) {
-			if ((result = use_toolkit(url, *id, url_toolkit, &new_url, ".", &toolkit_fastcgi)) == UT_ERROR) {
+			if ((result = use_toolkit(url, *id, &options)) == UT_ERROR) {
 				perror("use_toolkit()");
 			}
-			if (new_url != NULL) {
-				url = new_url;
+			if (options.new_url != NULL) {
+				url = options.new_url;
 			}
 			if (result == UT_REDIRECT) {
 				break;
@@ -642,23 +648,23 @@ void check_url_toolkit(char *config_dir, char **toolkit_id) {
 				url = "(403 Forbidden)";
 				break;
 			}
-			if (toolkit_fastcgi != NULL) {
+			if (options.fastcgi_server != NULL) {
 				break;
 			}
 			id++;
 		}
 
-		if (toolkit_fastcgi != NULL) {
-			printf("Using FastCGI server: %s\n", toolkit_fastcgi);
+		if (options.fastcgi_server != NULL) {
+			printf("Using FastCGI server: %s\n", options.fastcgi_server);
 		}
-		if (new_url != NULL) {
+		if (options.new_url != NULL) {
 			if (result == UT_REDIRECT) {
 				printf("Request is redirected.\n");
-			} else if (*new_url != '/') {
+			} else if (options.new_url[0] != '/') {
 				printf("Warning: your new URL is missing a leading slash!\n");
 			}
-			printf("new: %s\n\n", new_url);
-			free(new_url);
+			printf("new: %s\n\n", options.new_url);
+			free(options.new_url);
 		} else {
 			printf("old: %s\n\n", url);
 		}
